==> fltk-docs-1.3.5-4-x86_64.pkg.tar.zst: usr/share/doc/fltk/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "FLTK", "index.html", [
    [ "FLTK Programming Manual", "index.html", "index" ],
    [ "Todo List", "todo.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Enumerations_8H.html",
"Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a9edbfd236c9ea348dcaae935a76bd885",
"Fl__Paged__Device_8H.html#ad85fd91db75c56dcf6696635c1db0aff",
"classFl__Browser__.html#a2302bec54f4ea593146be5490a7fe93b",
"classFl__FLTK__File__Chooser.html#a94c93232b73eef3c6ee275d8fdbf7802",
"classFl__Graphics__Driver.html#a208595f1c4e4bd0c32ee5a56194b405c",
"classFl__Image.html#a7cf92084aede6baa2bdb00caa8f5a010",
"classFl__Overlay__Window.html#a6bdc30c7d7941e7542e230904bc9de2d",
"classFl__Preferences.html#a6602c3104b2c5259160cb7e0fe5dd335",
"classFl__Spinner.html#a4e2ea3fbdf8d7653d3dc1440d58434cf",
"classFl__Text__Buffer.html#a3194e63f030767326476d4e719d69a32",
"classFl__Text__Display.html#ae6ab1a7e2bdee0730730710c3e5e310f",
"classFl__Tree__Item.html#a1d92235d11914f88f3b232e509bd2514",
"classFl__Value__Output.html#a9c9b1bdb0f3862f7709aa56ae0c4182f",
"classFl__Xlib__Graphics__Driver.html#a2483bf6da5735a7141ada57b7eca2ae4",
"fl__boxtype_8cxx.html#a3d6c905e0e037c1f962f019679978d4c",
"glut_8H.html#adf764cbdea00d65edcd07bb9953ad2b7a563dde7b29f2a6d90dd96bb4a74752c5",
"group__fl__drawings.html#ga06fc87d81c62e9abb8790b6e5713c55ba9062ebd4dae14dde6a892ca36b429d6c",
"group__fl__drawings.html#gacf46b232b6439424cc7f53656c5c2226",
"group__group__comdlg.html#ga5cb8a823f404d44994862d198b3a82b1",
"structFl__Menu__Item.html#a6983103fb99e1fee59dd705bb2d23147"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> fltk-docs-1.3.8-2-x86_64.pkg.tar.zst: usr/share/doc/fltk/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "FLTK 1.3.8", "index.html", [
    [ "FLTK Programming Manual", "index.html", "index" ],
    [ "Todo List", "todo.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Enumerations_8H.html",
"Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcafaf89941b05600b6d4513e387d69cd36",
"classFl.html#a43e6e0bbbc03cad134d928d4edd48d1da2344bf14f80ecf5971e8aa4493a3858a",
"classFl__Color__Chooser.html#a267e63ddf0d5d1f03074d7d4339ba1fe",
"classFl__Graphics__Driver.html#a0b9590d3bc415c0cdb2ba2fb6dc589ad",
"classFl__Image.html#a64dbb6fe30e3080a24f718231b371a17",
"classFl__Pack.html#a8820c6b4dba2209ab4b650b3a04cde05",
"classFl__Printer.html#a82f5d6a0fe67c6b756251c6c2f470010",
"classFl__Table.html#a8f83d61e9c7ec6d19a49ad1ae1eb6ffc",
"classFl__Text__Display.html#af2d8e613a81bfea815288b9d77874b4b",
"classFl__Tree__Item.html#a64eabbcb09b56c83455866dbce18cc0c",
"classFl__Widget.html#a454a0be4839ea5ed2aa203d788bf840f",
"editor.html",
"functions.html",
"group__fl__drawings.html#ga14f28b302c1adf1f6dc76efbd6275a50",
"group__group__comdlg.html#ga36c19b29fcd5c261f3eafdf9f7126b16",
"structFl__Multi__Label.html#af72aa419e40c7a64116ea19f4fee4b98"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
